@@ -73,13 +73,20 @@ let s: &str = fmt.borrow();
 ```
 
 
+
+## Optional Crate Features
+
+* `serde`: Enables serialization/deserialization support.
+
+
+
 ## Installation
 
 Add `utc2k` to your `dependencies` in `Cargo.toml`, like:
 
 ```ignore,text
 [dependencies]
-utc2k = "0.1.*"
+utc2k = "0.2.*"
 ```
 */
 
@@ -107,14 +114,18 @@ utc2k = "0.1.*"
 
 
 
+mod abacus;
 mod date;
 mod error;
+mod weekday;
 
+pub(crate) use abacus::Abacus;
 pub use date::{
 	FmtUtc2k,
 	Utc2k,
 };
 pub use error::Utc2kError;
+pub use weekday::Weekday;
 
 
 
@@ -133,11 +144,10 @@ pub const WEEK_IN_SECONDS: u32 = 604_800;
 /// # Seconds per (Normal) Year.
 pub const YEAR_IN_SECONDS: u32 = 31_536_000;
 
-/// # Seconds Between 1970 and 2000.
-pub const OLD_SECONDS: u32 = 946_684_800;
-
 /// # Julian Day Epoch.
-pub const JULIAN_EPOCH: u32 = 2_440_588;
+///
+/// This is used internally when parsing date components from days.
+pub(crate) const JULIAN_EPOCH: u32 = 2_440_588;
 
 
 
